@@ -11,6 +11,8 @@ def assert_component_jdtextedit(component: appstream_python.AppstreamComponent)
     assert component.id == "com.gitlab.JakobDev.jdTextEdit"
     assert component.name.get_default_text() == "jdTextEdit"
     assert component.summary.get_default_text() == "An advanced text editor"
+    assert component.developer.name.get_default_text() == "JakobDev"
+    assert component.developer.id is None
     assert component.project_license == "GPL-3.0-only"
     assert component.metadata_license == "CC0-1.0"
     assert component.project_group is None
@@ -53,3 +55,19 @@ def test_from_string() -> None:
     with open(JDTEXTEDIT_METAINFO, "r") as f:
         component = appstream_python.AppstreamComponent.from_string(f.read())
     assert_component_jdtextedit(component)
+
+
+def test_save_jdtextedit_data(tmp_path: pathlib.Path) -> None:
+    old_component = appstream_python.AppstreamComponent.from_file(JDTEXTEDIT_METAINFO)
+    old_component.save_file(tmp_path / "jdTextEdit.metainfo.xml")
+
+    new_component = appstream_python.AppstreamComponent.from_file(tmp_path / "jdTextEdit.metainfo.xml")
+    assert_component_jdtextedit(new_component)
+
+
+def test_data_appstream_cli() -> None:
+    component = appstream_python.AppstreamComponent.from_file(DATA_DIR / "org.freedesktop.appstream.cli.metainfo.xml")
+
+    assert component.project_group == "Freedesktop"
+    assert component.developer.id == "org.freedesktop"
+    assert component.developer.name.get_default_text() == "Matthias Klumpp"
